Crate intasend

Crate intasend 

Re-exports

pub use rust_decimal;

Structs

CheckoutDetailsRequest
CheckoutDetailsRequest Struct - Checkout API
CheckoutDetailsResponse
CheckoutDetailsResponse Struct - Checkout API
CheckoutRequest
CheckoutRequest Struct - CheckoutsAPI
CheckoutResponse
CheckoutResponse Struct - CheckoutsAPI
CheckoutsAPI
Checkout struct implements methods for facilitating: Checkout Link API that allows you to generate a secure link that you can share with your customer to complete payment. Once the customer click on the link, IntaSend provides a guide on how to complete payment and notify both you and the customers on the status of the payment.
CollectionsAPI
Collection struct implements methods for facilitating: Mpesa Express for merchant initiated online payments
Customer
Customer struct
Decimal
Decimal represents a 128 bit representation of a fixed-precision decimal number. The finite set of values of type Decimal are of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.
FundCheckoutRequest
FundCheckoutRequest
FundCheckoutResponse
FundCheckoutResponse struct
FundMpesaRequest
FundMpesaRequest struct
FundMpesaResponse
FundMpesaResponse struct
Intasend
IntaSend - The Unofficial Rust Client SDK for the Intasend API Gateway.
IntasendApiError
IntasendApiError struct
IntasendApiErrorDetail
ApiErrorDatail struct
MpesaStkPushRequest
MPesaSTKPushRequest Struct - CollectionsAPI
MpesaStkPushResponse
MpesaStkPushResponse Struct - CollectionsAPI
PaymentLink
PaymentLink struct
PaymentLinksAPI
PaymentLinksAPI struct implements methods for facilitating:
PaymentLinksCreateDetails
PaymentLinksDetailsRequest
PaymentLinksListRequest
PaymentLinksListRequest struct
PaymentLinksListResponse
PaymentLinksListResponse struct
PaymentLinksUpdateDetails
Payout
Payout struct
PayoutApprovalRequest
PayoutApprovalRequest struct
PayoutRequest
PayoutRequest struct
PayoutRequestTransaction
PayoutRequestTransaction struct
PayoutResponseTransaction
PayoutResponseTransaction struct
PayoutStatusRequest
PayoutStatusRequest struct
PayoutsAPI
PayoutsAPI struct implements methods for facilitating: Sending of funds to different recipients programatically.
Refund
Refund struct
RefundListResponse
RefundListResponse struct
RefundRequest
RefundRequest struct
RefundsAPI
Refunds struct implements methods for facilitating: listing all refunds made by an entity, creating new refunds for specific transactions with its status completed, and also get a single specific refund made using the chargeback_id
StkPushStatusRequest
StkPushStatusRequest Struct - CollectionsAPI
StkPushStatusResponse
StkPushStatusResponse Struct - CollectionsAPI
Subscription
Subscription struct
SubscriptionsAPI
SubscriptionsAPI struct implements methods for facilitating:
SubscriptionsCreateDetails
SubscriptionsCreateDetails struct
SubscriptionsCustomer
SubscriptionsCustomer struct — the API CustomerSer response shape.
SubscriptionsCustomerCreateDetails
SubscriptionsCustomerCreateDetails struct — body for creating/updating a subscription customer.
SubscriptionsCustomerListResponse
SubscriptionsCustomerListResponse struct
SubscriptionsListResponse
SubscriptionsListResponse struct
SubscriptionsPlan
SubscriptionsPlan struct — the API PlanSer response shape.
SubscriptionsPlanCreateRequest
SubscriptionsPlanCreateRequest struct — body for creating/updating a subscription plan.
SubscriptionsPlanListResponse
SubscriptionsPlanListResponse struct
SubscriptionsTransactionListResponse
SubscriptionsTransactionListResponse — the subscription transactions endpoint returns a bare JSON array of transactions (not a paginated object), so this is a transparent newtype over the list. Access the inner items via .0.
Transaction
Transaction struct
Wallet
Wallet struct
WalletCreateDetails
WalletCreateDetails struct
WalletDetailsRequest
WalletDetailsRequeststruct
WalletIntraTransferRequest
WalletIntraTransferRequest struct
WalletIntraTransferResponse
WalletIntraTransferResponse struct
WalletListResponse
WalletListResponse struct
WalletTransactionsResponse
WalletTransactionsResponse struct
WalletsAPI
WalletsAPI struct implements methods for facilitating: listing all wallets managed with an API key, get details of a specific wallet using wallet_id, create new WORKING wallet types as sub-accounts for an associated IntaSend API key

Enums

CheckoutMethod
Checkout Options supported by Intasend API Gateway
Currency
Currencies supported by the IntaSend API Gateway.
FrequencyUnit
FrequencyUnit enum — the billing interval unit for a subscription plan.
IntasendClientError
IntasendClientError - The main error data structure derived from thiserror crate
PayoutApproval
PayoutApproval enum
PayoutProvider
Payout Provider Options supported by Intasend API Gateway
Provider
Provider enum - provided by IntaSend Checkout Options supported by Intasend API Gateway
RefundReason
RefundReason struct
SubscriptionStatus
SubscriptionStatus enum
Tarrif
Tarrifs supported by IntaSend
TransactionStatus
TransactionStatus enum
TransactionType
TransactionType enum
WalletType
WalletType enum