Re-exports
pub use rust_decimal;
Structs
- Checkout
Details Request CheckoutDetailsRequestStruct -CheckoutAPI- Checkout
Details Response CheckoutDetailsResponseStruct -CheckoutAPI- Checkout
Request CheckoutRequestStruct -CheckoutsAPI- Checkout
Response CheckoutResponseStruct -CheckoutsAPI- CheckoutsAPI
Checkoutstruct implements methods for facilitating: Checkout Link API that allows you to generate a secure link that you can share with your customer to complete payment. Once the customer click on the link, IntaSend provides a guide on how to complete payment and notify both you and the customers on the status of the payment.- CollectionsAPI
Collectionstruct implements methods for facilitating: Mpesa Express for merchant initiated online payments- Customer
Customerstruct- Decimal
Decimalrepresents a 128 bit representation of a fixed-precision decimal number. The finite set of values of typeDecimalare of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.- Fund
Checkout Request FundCheckoutRequest- Fund
Checkout Response FundCheckoutResponsestruct- Fund
Mpesa Request FundMpesaRequeststruct- Fund
Mpesa Response FundMpesaResponsestruct- Intasend
- IntaSend - The Unofficial Rust Client SDK for the Intasend API Gateway.
- Intasend
ApiError IntasendApiErrorstruct- Intasend
ApiError Detail ApiErrorDatailstruct- Mpesa
StkPush Request MPesaSTKPushRequestStruct -CollectionsAPI- Mpesa
StkPush Response MpesaStkPushResponseStruct -CollectionsAPI- Payment
Link PaymentLinkstruct- Payment
LinksAPI PaymentLinksAPIstruct implements methods for facilitating:- Payment
Links Create Details - Payment
Links Details Request - Payment
Links List Request PaymentLinksListRequeststruct- Payment
Links List Response PaymentLinksListResponsestruct- Payment
Links Update Details - Payout
Payoutstruct- Payout
Approval Request PayoutApprovalRequeststruct- Payout
Request PayoutRequeststruct- Payout
Request Transaction PayoutRequestTransactionstruct- Payout
Response Transaction PayoutResponseTransactionstruct- Payout
Status Request PayoutStatusRequeststruct- PayoutsAPI
PayoutsAPIstruct implements methods for facilitating: Sending of funds to different recipients programatically.- Refund
Refundstruct- Refund
List Response RefundListResponsestruct- Refund
Request RefundRequeststruct- RefundsAPI
Refundsstruct implements methods for facilitating: listing all refunds made by an entity, creating new refunds for specific transactions with its status completed, and also get a single specific refund made using thechargeback_id- StkPush
Status Request StkPushStatusRequestStruct -CollectionsAPI- StkPush
Status Response StkPushStatusResponseStruct -CollectionsAPI- Subscription
Subscriptionstruct- SubscriptionsAPI
SubscriptionsAPIstruct implements methods for facilitating:- Subscriptions
Create Details SubscriptionsCreateDetailsstruct- Subscriptions
Customer SubscriptionsCustomerstruct — the APICustomerSerresponse shape.- Subscriptions
Customer Create Details SubscriptionsCustomerCreateDetailsstruct — body for creating/updating a subscription customer.- Subscriptions
Customer List Response SubscriptionsCustomerListResponsestruct- Subscriptions
List Response SubscriptionsListResponsestruct- Subscriptions
Plan SubscriptionsPlanstruct — the APIPlanSerresponse shape.- Subscriptions
Plan Create Request SubscriptionsPlanCreateRequeststruct — body for creating/updating a subscription plan.- Subscriptions
Plan List Response SubscriptionsPlanListResponsestruct- Subscriptions
Transaction List Response SubscriptionsTransactionListResponse— the subscription transactions endpoint returns a bare JSON array of transactions (not a paginated object), so this is a transparent newtype over the list. Access the inner items via.0.- Transaction
Transactionstruct- Wallet
Walletstruct- Wallet
Create Details WalletCreateDetailsstruct- Wallet
Details Request WalletDetailsRequeststruct- Wallet
Intra Transfer Request WalletIntraTransferRequeststruct- Wallet
Intra Transfer Response WalletIntraTransferResponsestruct- Wallet
List Response WalletListResponsestruct- Wallet
Transactions Response WalletTransactionsResponsestruct- WalletsAPI
WalletsAPIstruct implements methods for facilitating: listing all wallets managed with an API key, get details of a specific wallet usingwallet_id, create newWORKINGwallet types as sub-accounts for an associated IntaSend API key
Enums
- Checkout
Method CheckoutOptions supported byIntasendAPI Gateway- Currency
- Currencies supported by the IntaSend API Gateway.
- Frequency
Unit FrequencyUnitenum — the billing interval unit for a subscription plan.- Intasend
Client Error IntasendClientError- The main error data structure derived fromthiserrorcrate- Payout
Approval PayoutApprovalenum- Payout
Provider - Payout Provider Options supported by Intasend API Gateway
- Provider
Providerenum - provided by IntaSend Checkout Options supported by Intasend API Gateway- Refund
Reason RefundReasonstruct- Subscription
Status SubscriptionStatusenum- Tarrif
- Tarrifs supported by IntaSend
- Transaction
Status TransactionStatusenum- Transaction
Type TransactionTypeenum- Wallet
Type WalletTypeenum